summaryrefslogtreecommitdiff
path: root/sys/dev/ic/bcwvar.h
diff options
context:
space:
mode:
authorMarcus Glocker <mglocker@cvs.openbsd.org>2007-02-24 23:05:05 +0000
committerMarcus Glocker <mglocker@cvs.openbsd.org>2007-02-24 23:05:05 +0000
commit580cb8acd3312b1a12ff95f27f5417f975292863 (patch)
treedd9dea86fe57ea66c8fa69f1653cdf0e4c22900d /sys/dev/ic/bcwvar.h
parent927e7acd301e5d8d9836e39ba782f84551cadbab (diff)
Get correct chip revision and also get chip package.
Diffstat (limited to 'sys/dev/ic/bcwvar.h')
-rw-r--r--sys/dev/ic/bcwvar.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/sys/dev/ic/bcwvar.h b/sys/dev/ic/bcwvar.h
index 063afd0164b..de52210453f 100644
--- a/sys/dev/ic/bcwvar.h
+++ b/sys/dev/ic/bcwvar.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: bcwvar.h,v 1.22 2007/02/24 11:59:33 mglocker Exp $ */
+/* $OpenBSD: bcwvar.h,v 1.23 2007/02/24 23:05:04 mglocker Exp $ */
/*
* Copyright (c) 2006 Jon Simola <jsimola@gmail.com>
@@ -223,8 +223,9 @@ struct bcw_softc {
int sc_txsnext; /* next available tx slot */
struct timeout sc_timeout;
/* Break these out into seperate structs */
- uint16_t sc_chipid; /* Chip ID */
- uint16_t sc_chiprev; /* Chip Revision */
+ uint16_t sc_chip_id; /* Chip ID */
+ uint16_t sc_chip_rev; /* Chip Revision */
+ uint16_t sc_chip_package; /* Chip Package */
uint16_t sc_prodid; /* Product ID */
struct bcw_core sc_core[BCW_MAX_CORES];
// struct bcw_radio radio[BCW_RADIO_MAX];